# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertArgs', 'Alert']

@pulumi.input_type
class AlertArgs:
    def __init__(__self__, *,
                 condition: pulumi.Input['AlertConditionArgs'],
                 display_name: pulumi.Input[_builtins.str],
                 query_id: pulumi.Input[_builtins.str],
                 custom_body: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_subject: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_on_ok: Optional[pulumi.Input[_builtins.bool]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AlertProviderConfigArgs']] = None,
                 seconds_to_retrigger: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a Alert resource.
        :param pulumi.Input['AlertConditionArgs'] condition: Trigger conditions of the alert. Block consists of the following attributes:
        :param pulumi.Input[_builtins.str] display_name: Name of the alert.
        :param pulumi.Input[_builtins.str] query_id: ID of the query evaluated by the alert.
        :param pulumi.Input[_builtins.str] custom_body: Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] custom_subject: Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.bool] notify_on_ok: Whether to notify alert subscribers when alert returns back to normal.
        :param pulumi.Input[_builtins.str] owner_user_name: Alert owner's username.
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        :param pulumi.Input['AlertProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.int] seconds_to_retrigger: Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        """
        pulumi.set(__self__, "condition", condition)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "query_id", query_id)
        if custom_body is not None:
            pulumi.set(__self__, "custom_body", custom_body)
        if custom_subject is not None:
            pulumi.set(__self__, "custom_subject", custom_subject)
        if notify_on_ok is not None:
            pulumi.set(__self__, "notify_on_ok", notify_on_ok)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if seconds_to_retrigger is not None:
            pulumi.set(__self__, "seconds_to_retrigger", seconds_to_retrigger)

    @_builtins.property
    @pulumi.getter
    def condition(self) -> pulumi.Input['AlertConditionArgs']:
        """
        Trigger conditions of the alert. Block consists of the following attributes:
        """
        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: pulumi.Input['AlertConditionArgs']):
        pulumi.set(self, "condition", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the alert.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the query evaluated by the alert.
        """
        return pulumi.get(self, "query_id")

    @query_id.setter
    def query_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "query_id", value)

    @_builtins.property
    @pulumi.getter(name="customBody")
    def custom_body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_body")

    @custom_body.setter
    def custom_body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_body", value)

    @_builtins.property
    @pulumi.getter(name="customSubject")
    def custom_subject(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_subject")

    @custom_subject.setter
    def custom_subject(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_subject", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnOk")
    def notify_on_ok(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify alert subscribers when alert returns back to normal.
        """
        return pulumi.get(self, "notify_on_ok")

    @notify_on_ok.setter
    def notify_on_ok(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_ok", value)

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Alert owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AlertProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AlertProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="secondsToRetrigger")
    def seconds_to_retrigger(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        """
        return pulumi.get(self, "seconds_to_retrigger")

    @seconds_to_retrigger.setter
    def seconds_to_retrigger(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "seconds_to_retrigger", value)


@pulumi.input_type
class _AlertState:
    def __init__(__self__, *,
                 condition: Optional[pulumi.Input['AlertConditionArgs']] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_body: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_subject: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_on_ok: Optional[pulumi.Input[_builtins.bool]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AlertProviderConfigArgs']] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 seconds_to_retrigger: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 trigger_time: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Alert resources.
        :param pulumi.Input['AlertConditionArgs'] condition: Trigger conditions of the alert. Block consists of the following attributes:
        :param pulumi.Input[_builtins.str] create_time: The timestamp string indicating when the alert was created.
        :param pulumi.Input[_builtins.str] custom_body: Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] custom_subject: Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] display_name: Name of the alert.
        :param pulumi.Input[_builtins.str] lifecycle_state: The workspace state of the alert. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        :param pulumi.Input[_builtins.bool] notify_on_ok: Whether to notify alert subscribers when alert returns back to normal.
        :param pulumi.Input[_builtins.str] owner_user_name: Alert owner's username.
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        :param pulumi.Input['AlertProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_id: ID of the query evaluated by the alert.
        :param pulumi.Input[_builtins.int] seconds_to_retrigger: Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        :param pulumi.Input[_builtins.str] state: Current state of the alert's trigger status (`UNKNOWN`, `OK`, `TRIGGERED`). This field is set to `UNKNOWN` if the alert has not yet been evaluated or ran into an error during the last evaluation.
        :param pulumi.Input[_builtins.str] trigger_time: The timestamp string when the alert was last triggered if the alert has been triggered before.
        :param pulumi.Input[_builtins.str] update_time: The timestamp string indicating when the alert was updated.
        """
        if condition is not None:
            pulumi.set(__self__, "condition", condition)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if custom_body is not None:
            pulumi.set(__self__, "custom_body", custom_body)
        if custom_subject is not None:
            pulumi.set(__self__, "custom_subject", custom_subject)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if notify_on_ok is not None:
            pulumi.set(__self__, "notify_on_ok", notify_on_ok)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if query_id is not None:
            pulumi.set(__self__, "query_id", query_id)
        if seconds_to_retrigger is not None:
            pulumi.set(__self__, "seconds_to_retrigger", seconds_to_retrigger)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if trigger_time is not None:
            pulumi.set(__self__, "trigger_time", trigger_time)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter
    def condition(self) -> Optional[pulumi.Input['AlertConditionArgs']]:
        """
        Trigger conditions of the alert. Block consists of the following attributes:
        """
        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: Optional[pulumi.Input['AlertConditionArgs']]):
        pulumi.set(self, "condition", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp string indicating when the alert was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="customBody")
    def custom_body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_body")

    @custom_body.setter
    def custom_body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_body", value)

    @_builtins.property
    @pulumi.getter(name="customSubject")
    def custom_subject(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_subject")

    @custom_subject.setter
    def custom_subject(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_subject", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the alert.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The workspace state of the alert. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnOk")
    def notify_on_ok(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify alert subscribers when alert returns back to normal.
        """
        return pulumi.get(self, "notify_on_ok")

    @notify_on_ok.setter
    def notify_on_ok(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_ok", value)

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Alert owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AlertProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AlertProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the query evaluated by the alert.
        """
        return pulumi.get(self, "query_id")

    @query_id.setter
    def query_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_id", value)

    @_builtins.property
    @pulumi.getter(name="secondsToRetrigger")
    def seconds_to_retrigger(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        """
        return pulumi.get(self, "seconds_to_retrigger")

    @seconds_to_retrigger.setter
    def seconds_to_retrigger(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "seconds_to_retrigger", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Current state of the alert's trigger status (`UNKNOWN`, `OK`, `TRIGGERED`). This field is set to `UNKNOWN` if the alert has not yet been evaluated or ran into an error during the last evaluation.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter(name="triggerTime")
    def trigger_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp string when the alert was last triggered if the alert has been triggered before.
        """
        return pulumi.get(self, "trigger_time")

    @trigger_time.setter
    def trigger_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "trigger_time", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp string indicating when the alert was updated.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("databricks:index/alert:Alert")
class Alert(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition: Optional[pulumi.Input[Union['AlertConditionArgs', 'AlertConditionArgsDict']]] = None,
                 custom_body: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_subject: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_on_ok: Optional[pulumi.Input[_builtins.bool]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AlertProviderConfigArgs', 'AlertProviderConfigArgsDict']]] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 seconds_to_retrigger: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        This resource allows you to manage [Databricks SQL Alerts](https://docs.databricks.com/en/sql/user/alerts/index.html).  It supersedes SqlAlert resource - see migration guide below for more details.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        shared_dir = databricks.Directory("shared_dir", path="/Shared/Queries")
        # This will be replaced with new databricks_query resource
        this = databricks.Query("this",
            warehouse_id=example["id"],
            display_name="My Query Name",
            query_text="SELECT 42 as value",
            parent_path=shared_dir.path)
        alert = databricks.Alert("alert",
            query_id=this.id,
            display_name="TF new alert",
            parent_path=shared_dir.path,
            condition={
                "op": "GREATER_THAN",
                "operand": {
                    "column": {
                        "name": "value",
                    },
                },
                "threshold": {
                    "value": {
                        "double_value": 42,
                    },
                },
            })
        ```

        ## Migrating from `SqlAlert` resource

        Under the hood, the new resource uses the same data as the `SqlAlert`, but is exposed via a different API. This means that we can migrate existing alerts without recreating them.

        > It's also recommended to migrate to the `Query` resource - see Query for more details.

        This operation is done in few steps:

        * Record the ID of existing `SqlAlert`, for example, by executing the `terraform state show databricks_sql_alert.alert` command.
        * Create the code for the new implementation by performing the following changes:
          * the `name` attribute is now named `display_name`
          * the `parent` (if exists) is renamed to `parent_path` attribute and should be converted from `folders/object_id` to the actual path.
          * the `options` block is converted into the `condition` block with the following changes:
            * the value of the `op` attribute should be converted from a mathematical operator into a string name, like, `>` is becoming `GREATER_THAN`, `==` is becoming `EQUAL`, etc.
            * the `column` attribute is becoming the `operand` block
            * the `value` attribute is becoming the `threshold` block.  **Please note that the old implementation always used strings so you may have changes after import if you use `double_value` or `bool_value` inside the block.**
          * the `rearm` attribute is renamed to `seconds_to_retrigger`.

        For example, if we have the original `SqlAlert` defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert = databricks.SqlAlert("alert",
            query_id=this["id"],
            name="My Alert",
            parent=f"folders/{shared_dir['objectId']}",
            options={
                "column": "value",
                "op": ">",
                "value": "42",
                "muted": False,
            })
        ```

        we'll have a new resource defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert = databricks.Alert("alert",
            query_id=this["id"],
            display_name="My Alert",
            parent_path=shared_dir["path"],
            condition={
                "op": "GREATER_THAN",
                "operand": {
                    "column": {
                        "name": "value",
                    },
                },
                "threshold": {
                    "value": {
                        "double_value": 42,
                    },
                },
            })
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual alerts.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert_usage = databricks.Permissions("alert_usage",
            sql_alert_id=alert["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual alerts.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert_usage = databricks.Permissions("alert_usage",
            sql_alert_id=alert["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Query to manage [Databricks SQL Queries](https://docs.databricks.com/sql/user/queries/index.html).
        * SqlEndpoint to manage [Databricks SQL Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AlertConditionArgs', 'AlertConditionArgsDict']] condition: Trigger conditions of the alert. Block consists of the following attributes:
        :param pulumi.Input[_builtins.str] custom_body: Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] custom_subject: Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] display_name: Name of the alert.
        :param pulumi.Input[_builtins.bool] notify_on_ok: Whether to notify alert subscribers when alert returns back to normal.
        :param pulumi.Input[_builtins.str] owner_user_name: Alert owner's username.
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        :param pulumi.Input[Union['AlertProviderConfigArgs', 'AlertProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_id: ID of the query evaluated by the alert.
        :param pulumi.Input[_builtins.int] seconds_to_retrigger: Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage [Databricks SQL Alerts](https://docs.databricks.com/en/sql/user/alerts/index.html).  It supersedes SqlAlert resource - see migration guide below for more details.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        shared_dir = databricks.Directory("shared_dir", path="/Shared/Queries")
        # This will be replaced with new databricks_query resource
        this = databricks.Query("this",
            warehouse_id=example["id"],
            display_name="My Query Name",
            query_text="SELECT 42 as value",
            parent_path=shared_dir.path)
        alert = databricks.Alert("alert",
            query_id=this.id,
            display_name="TF new alert",
            parent_path=shared_dir.path,
            condition={
                "op": "GREATER_THAN",
                "operand": {
                    "column": {
                        "name": "value",
                    },
                },
                "threshold": {
                    "value": {
                        "double_value": 42,
                    },
                },
            })
        ```

        ## Migrating from `SqlAlert` resource

        Under the hood, the new resource uses the same data as the `SqlAlert`, but is exposed via a different API. This means that we can migrate existing alerts without recreating them.

        > It's also recommended to migrate to the `Query` resource - see Query for more details.

        This operation is done in few steps:

        * Record the ID of existing `SqlAlert`, for example, by executing the `terraform state show databricks_sql_alert.alert` command.
        * Create the code for the new implementation by performing the following changes:
          * the `name` attribute is now named `display_name`
          * the `parent` (if exists) is renamed to `parent_path` attribute and should be converted from `folders/object_id` to the actual path.
          * the `options` block is converted into the `condition` block with the following changes:
            * the value of the `op` attribute should be converted from a mathematical operator into a string name, like, `>` is becoming `GREATER_THAN`, `==` is becoming `EQUAL`, etc.
            * the `column` attribute is becoming the `operand` block
            * the `value` attribute is becoming the `threshold` block.  **Please note that the old implementation always used strings so you may have changes after import if you use `double_value` or `bool_value` inside the block.**
          * the `rearm` attribute is renamed to `seconds_to_retrigger`.

        For example, if we have the original `SqlAlert` defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert = databricks.SqlAlert("alert",
            query_id=this["id"],
            name="My Alert",
            parent=f"folders/{shared_dir['objectId']}",
            options={
                "column": "value",
                "op": ">",
                "value": "42",
                "muted": False,
            })
        ```

        we'll have a new resource defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert = databricks.Alert("alert",
            query_id=this["id"],
            display_name="My Alert",
            parent_path=shared_dir["path"],
            condition={
                "op": "GREATER_THAN",
                "operand": {
                    "column": {
                        "name": "value",
                    },
                },
                "threshold": {
                    "value": {
                        "double_value": 42,
                    },
                },
            })
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual alerts.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert_usage = databricks.Permissions("alert_usage",
            sql_alert_id=alert["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual alerts.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        alert_usage = databricks.Permissions("alert_usage",
            sql_alert_id=alert["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Query to manage [Databricks SQL Queries](https://docs.databricks.com/sql/user/queries/index.html).
        * SqlEndpoint to manage [Databricks SQL Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).

        :param str resource_name: The name of the resource.
        :param AlertArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition: Optional[pulumi.Input[Union['AlertConditionArgs', 'AlertConditionArgsDict']]] = None,
                 custom_body: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_subject: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_on_ok: Optional[pulumi.Input[_builtins.bool]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AlertProviderConfigArgs', 'AlertProviderConfigArgsDict']]] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 seconds_to_retrigger: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertArgs.__new__(AlertArgs)

            if condition is None and not opts.urn:
                raise TypeError("Missing required property 'condition'")
            __props__.__dict__["condition"] = condition
            __props__.__dict__["custom_body"] = custom_body
            __props__.__dict__["custom_subject"] = custom_subject
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["notify_on_ok"] = notify_on_ok
            __props__.__dict__["owner_user_name"] = owner_user_name
            __props__.__dict__["parent_path"] = parent_path
            __props__.__dict__["provider_config"] = provider_config
            if query_id is None and not opts.urn:
                raise TypeError("Missing required property 'query_id'")
            __props__.__dict__["query_id"] = query_id
            __props__.__dict__["seconds_to_retrigger"] = seconds_to_retrigger
            __props__.__dict__["create_time"] = None
            __props__.__dict__["lifecycle_state"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["trigger_time"] = None
            __props__.__dict__["update_time"] = None
        super(Alert, __self__).__init__(
            'databricks:index/alert:Alert',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            condition: Optional[pulumi.Input[Union['AlertConditionArgs', 'AlertConditionArgsDict']]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            custom_body: Optional[pulumi.Input[_builtins.str]] = None,
            custom_subject: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
            notify_on_ok: Optional[pulumi.Input[_builtins.bool]] = None,
            owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
            parent_path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['AlertProviderConfigArgs', 'AlertProviderConfigArgsDict']]] = None,
            query_id: Optional[pulumi.Input[_builtins.str]] = None,
            seconds_to_retrigger: Optional[pulumi.Input[_builtins.int]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            trigger_time: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None) -> 'Alert':
        """
        Get an existing Alert resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AlertConditionArgs', 'AlertConditionArgsDict']] condition: Trigger conditions of the alert. Block consists of the following attributes:
        :param pulumi.Input[_builtins.str] create_time: The timestamp string indicating when the alert was created.
        :param pulumi.Input[_builtins.str] custom_body: Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] custom_subject: Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        :param pulumi.Input[_builtins.str] display_name: Name of the alert.
        :param pulumi.Input[_builtins.str] lifecycle_state: The workspace state of the alert. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        :param pulumi.Input[_builtins.bool] notify_on_ok: Whether to notify alert subscribers when alert returns back to normal.
        :param pulumi.Input[_builtins.str] owner_user_name: Alert owner's username.
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        :param pulumi.Input[Union['AlertProviderConfigArgs', 'AlertProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_id: ID of the query evaluated by the alert.
        :param pulumi.Input[_builtins.int] seconds_to_retrigger: Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        :param pulumi.Input[_builtins.str] state: Current state of the alert's trigger status (`UNKNOWN`, `OK`, `TRIGGERED`). This field is set to `UNKNOWN` if the alert has not yet been evaluated or ran into an error during the last evaluation.
        :param pulumi.Input[_builtins.str] trigger_time: The timestamp string when the alert was last triggered if the alert has been triggered before.
        :param pulumi.Input[_builtins.str] update_time: The timestamp string indicating when the alert was updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertState.__new__(_AlertState)

        __props__.__dict__["condition"] = condition
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["custom_body"] = custom_body
        __props__.__dict__["custom_subject"] = custom_subject
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["notify_on_ok"] = notify_on_ok
        __props__.__dict__["owner_user_name"] = owner_user_name
        __props__.__dict__["parent_path"] = parent_path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["query_id"] = query_id
        __props__.__dict__["seconds_to_retrigger"] = seconds_to_retrigger
        __props__.__dict__["state"] = state
        __props__.__dict__["trigger_time"] = trigger_time
        __props__.__dict__["update_time"] = update_time
        return Alert(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def condition(self) -> pulumi.Output['outputs.AlertCondition']:
        """
        Trigger conditions of the alert. Block consists of the following attributes:
        """
        return pulumi.get(self, "condition")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp string indicating when the alert was created.
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="customBody")
    def custom_body(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom body of alert notification, if it exists. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_body")

    @_builtins.property
    @pulumi.getter(name="customSubject")
    def custom_subject(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom subject of alert notification, if it exists. This includes email subject, Slack notification header, etc. See [Alerts API reference](https://docs.databricks.com/en/sql/user/alerts/index.html) for custom templating instructions.
        """
        return pulumi.get(self, "custom_subject")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the alert.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[_builtins.str]:
        """
        The workspace state of the alert. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter(name="notifyOnOk")
    def notify_on_ok(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to notify alert subscribers when alert returns back to normal.
        """
        return pulumi.get(self, "notify_on_ok")

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Alert owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The path to a workspace folder containing the alert. The default is the user's home folder.  If changed, the alert will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AlertProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the query evaluated by the alert.
        """
        return pulumi.get(self, "query_id")

    @_builtins.property
    @pulumi.getter(name="secondsToRetrigger")
    def seconds_to_retrigger(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Number of seconds an alert must wait after being triggered to rearm itself. After rearming, it can be triggered again. If 0 or not specified, the alert will not be triggered again.
        """
        return pulumi.get(self, "seconds_to_retrigger")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        Current state of the alert's trigger status (`UNKNOWN`, `OK`, `TRIGGERED`). This field is set to `UNKNOWN` if the alert has not yet been evaluated or ran into an error during the last evaluation.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="triggerTime")
    def trigger_time(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp string when the alert was last triggered if the alert has been triggered before.
        """
        return pulumi.get(self, "trigger_time")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp string indicating when the alert was updated.
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TagPolicyArgs', 'TagPolicy']

@pulumi.input_type
class TagPolicyArgs:
    def __init__(__self__, *,
                 tag_key: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['TagPolicyProviderConfigArgs']] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]] = None):
        """
        The set of arguments for constructing a TagPolicy resource.
        :param pulumi.Input['TagPolicyProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "tag_key", tag_key)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['TagPolicyProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['TagPolicyProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]):
        pulumi.set(self, "values", value)


@pulumi.input_type
class _TagPolicyState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['TagPolicyProviderConfigArgs']] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]] = None):
        """
        Input properties used for looking up and filtering TagPolicy resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when the tag policy was created
        :param pulumi.Input['TagPolicyProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] update_time: (string) - Timestamp when the tag policy was last updated
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tag_key is not None:
            pulumi.set(__self__, "tag_key", tag_key)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp when the tag policy was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['TagPolicyProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['TagPolicyProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp when the tag policy was last updated
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]):
        pulumi.set(self, "values", value)


@pulumi.type_token("databricks:index/tagPolicy:TagPolicy")
class TagPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['TagPolicyProviderConfigArgs', 'TagPolicyProviderConfigArgsDict']]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Define tag policies to manage governed tags in your account.

        The following resources are often used in the same context:

        * EntityTagAssignment for assigning tags to supported Unity Catalog entities.
        * WorkspaceEntityTagAssignment for assigning tags to supported workspace entities.
        * PolicyInfo for defining ABAC policies using governed tags.
        * AccessControlRuleSet for managing account-level and individual tag policy permissions.

        > **Note** This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        example_tag_policy = databricks.TagPolicy("example_tag_policy",
            tag_key="example_tag_key",
            description="Example description.",
            values=[
                {
                    "name": "example_value_1",
                },
                {
                    "name": "example_value_2",
                },
                {
                    "name": "example_value_3",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TagPolicyProviderConfigArgs', 'TagPolicyProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TagPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Define tag policies to manage governed tags in your account.

        The following resources are often used in the same context:

        * EntityTagAssignment for assigning tags to supported Unity Catalog entities.
        * WorkspaceEntityTagAssignment for assigning tags to supported workspace entities.
        * PolicyInfo for defining ABAC policies using governed tags.
        * AccessControlRuleSet for managing account-level and individual tag policy permissions.

        > **Note** This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        example_tag_policy = databricks.TagPolicy("example_tag_policy",
            tag_key="example_tag_key",
            description="Example description.",
            values=[
                {
                    "name": "example_value_1",
                },
                {
                    "name": "example_value_2",
                },
                {
                    "name": "example_value_3",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param TagPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TagPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['TagPolicyProviderConfigArgs', 'TagPolicyProviderConfigArgsDict']]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TagPolicyArgs.__new__(TagPolicyArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["provider_config"] = provider_config
            if tag_key is None and not opts.urn:
                raise TypeError("Missing required property 'tag_key'")
            __props__.__dict__["tag_key"] = tag_key
            __props__.__dict__["values"] = values
            __props__.__dict__["create_time"] = None
            __props__.__dict__["update_time"] = None
        super(TagPolicy, __self__).__init__(
            'databricks:index/tagPolicy:TagPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['TagPolicyProviderConfigArgs', 'TagPolicyProviderConfigArgsDict']]] = None,
            tag_key: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None) -> 'TagPolicy':
        """
        Get an existing TagPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when the tag policy was created
        :param pulumi.Input[Union['TagPolicyProviderConfigArgs', 'TagPolicyProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] update_time: (string) - Timestamp when the tag policy was last updated
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TagPolicyState.__new__(_TagPolicyState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["tag_key"] = tag_key
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["values"] = values
        return TagPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp when the tag policy was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.TagPolicyProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "tag_key")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp when the tag policy was last updated
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter
    def values(self) -> pulumi.Output[Optional[Sequence['outputs.TagPolicyValue']]]:
        return pulumi.get(self, "values")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomAppIntegrationArgs', 'CustomAppIntegration']

@pulumi.input_type
class CustomAppIntegrationArgs:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 confidential: Optional[pulumi.Input[_builtins.bool]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 creator_username: Optional[pulumi.Input[_builtins.str]] = None,
                 integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 redirect_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_access_policy: Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']] = None,
                 user_authorized_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a CustomAppIntegration resource.
        :param pulumi.Input[_builtins.str] client_id: OAuth client-id generated by Databricks
        :param pulumi.Input[_builtins.str] client_secret: OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        :param pulumi.Input[_builtins.bool] confidential: Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        :param pulumi.Input[_builtins.str] integration_id: Unique integration id for the custom OAuth app.
        :param pulumi.Input[_builtins.str] name: Name of the custom OAuth app. Change requires a new resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] redirect_urls: List of OAuth redirect urls.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if confidential is not None:
            pulumi.set(__self__, "confidential", confidential)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if creator_username is not None:
            pulumi.set(__self__, "creator_username", creator_username)
        if integration_id is not None:
            pulumi.set(__self__, "integration_id", integration_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if redirect_urls is not None:
            pulumi.set(__self__, "redirect_urls", redirect_urls)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token_access_policy is not None:
            pulumi.set(__self__, "token_access_policy", token_access_policy)
        if user_authorized_scopes is not None:
            pulumi.set(__self__, "user_authorized_scopes", user_authorized_scopes)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        OAuth client-id generated by Databricks
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @_builtins.property
    @pulumi.getter
    def confidential(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        """
        return pulumi.get(self, "confidential")

    @confidential.setter
    def confidential(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "confidential", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="creatorUsername")
    def creator_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "creator_username")

    @creator_username.setter
    def creator_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator_username", value)

    @_builtins.property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique integration id for the custom OAuth app.
        """
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "integration_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the custom OAuth app. Change requires a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="redirectUrls")
    def redirect_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of OAuth redirect urls.
        """
        return pulumi.get(self, "redirect_urls")

    @redirect_urls.setter
    def redirect_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "redirect_urls", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter(name="tokenAccessPolicy")
    def token_access_policy(self) -> Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']]:
        return pulumi.get(self, "token_access_policy")

    @token_access_policy.setter
    def token_access_policy(self, value: Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']]):
        pulumi.set(self, "token_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="userAuthorizedScopes")
    def user_authorized_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "user_authorized_scopes")

    @user_authorized_scopes.setter
    def user_authorized_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_authorized_scopes", value)


@pulumi.input_type
class _CustomAppIntegrationState:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 confidential: Optional[pulumi.Input[_builtins.bool]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 creator_username: Optional[pulumi.Input[_builtins.str]] = None,
                 integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 redirect_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_access_policy: Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']] = None,
                 user_authorized_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering CustomAppIntegration resources.
        :param pulumi.Input[_builtins.str] client_id: OAuth client-id generated by Databricks
        :param pulumi.Input[_builtins.str] client_secret: OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        :param pulumi.Input[_builtins.bool] confidential: Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        :param pulumi.Input[_builtins.str] integration_id: Unique integration id for the custom OAuth app.
        :param pulumi.Input[_builtins.str] name: Name of the custom OAuth app. Change requires a new resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] redirect_urls: List of OAuth redirect urls.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if confidential is not None:
            pulumi.set(__self__, "confidential", confidential)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if creator_username is not None:
            pulumi.set(__self__, "creator_username", creator_username)
        if integration_id is not None:
            pulumi.set(__self__, "integration_id", integration_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if redirect_urls is not None:
            pulumi.set(__self__, "redirect_urls", redirect_urls)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token_access_policy is not None:
            pulumi.set(__self__, "token_access_policy", token_access_policy)
        if user_authorized_scopes is not None:
            pulumi.set(__self__, "user_authorized_scopes", user_authorized_scopes)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        OAuth client-id generated by Databricks
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @_builtins.property
    @pulumi.getter
    def confidential(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        """
        return pulumi.get(self, "confidential")

    @confidential.setter
    def confidential(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "confidential", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="creatorUsername")
    def creator_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "creator_username")

    @creator_username.setter
    def creator_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator_username", value)

    @_builtins.property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique integration id for the custom OAuth app.
        """
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "integration_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the custom OAuth app. Change requires a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="redirectUrls")
    def redirect_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of OAuth redirect urls.
        """
        return pulumi.get(self, "redirect_urls")

    @redirect_urls.setter
    def redirect_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "redirect_urls", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter(name="tokenAccessPolicy")
    def token_access_policy(self) -> Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']]:
        return pulumi.get(self, "token_access_policy")

    @token_access_policy.setter
    def token_access_policy(self, value: Optional[pulumi.Input['CustomAppIntegrationTokenAccessPolicyArgs']]):
        pulumi.set(self, "token_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="userAuthorizedScopes")
    def user_authorized_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "user_authorized_scopes")

    @user_authorized_scopes.setter
    def user_authorized_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_authorized_scopes", value)


@pulumi.type_token("databricks:index/customAppIntegration:CustomAppIntegration")
class CustomAppIntegration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 confidential: Optional[pulumi.Input[_builtins.bool]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 creator_username: Optional[pulumi.Input[_builtins.str]] = None,
                 integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 redirect_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_access_policy: Optional[pulumi.Input[Union['CustomAppIntegrationTokenAccessPolicyArgs', 'CustomAppIntegrationTokenAccessPolicyArgsDict']]] = None,
                 user_authorized_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        This resource allows you to enable [custom OAuth applications](https://docs.databricks.com/en/integrations/enable-disable-oauth.html#enable-custom-oauth-applications-using-the-databricks-ui).

        > This resource can only be used with an account-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.CustomAppIntegration("this",
            name="custom_integration_name",
            redirect_urls=["https://example.com"],
            scopes=["all-apis"],
            token_access_policy={
                "access_token_ttl_in_minutes": 15,
                "refresh_token_ttl_in_minutes": 30,
            })
        ```

        ## Related Resources

        The following resources are used in the context:

        * MwsWorkspaces to set up Databricks workspaces.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: OAuth client-id generated by Databricks
        :param pulumi.Input[_builtins.str] client_secret: OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        :param pulumi.Input[_builtins.bool] confidential: Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        :param pulumi.Input[_builtins.str] integration_id: Unique integration id for the custom OAuth app.
        :param pulumi.Input[_builtins.str] name: Name of the custom OAuth app. Change requires a new resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] redirect_urls: List of OAuth redirect urls.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CustomAppIntegrationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to enable [custom OAuth applications](https://docs.databricks.com/en/integrations/enable-disable-oauth.html#enable-custom-oauth-applications-using-the-databricks-ui).

        > This resource can only be used with an account-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.CustomAppIntegration("this",
            name="custom_integration_name",
            redirect_urls=["https://example.com"],
            scopes=["all-apis"],
            token_access_policy={
                "access_token_ttl_in_minutes": 15,
                "refresh_token_ttl_in_minutes": 30,
            })
        ```

        ## Related Resources

        The following resources are used in the context:

        * MwsWorkspaces to set up Databricks workspaces.

        :param str resource_name: The name of the resource.
        :param CustomAppIntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomAppIntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 confidential: Optional[pulumi.Input[_builtins.bool]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 creator_username: Optional[pulumi.Input[_builtins.str]] = None,
                 integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 redirect_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_access_policy: Optional[pulumi.Input[Union['CustomAppIntegrationTokenAccessPolicyArgs', 'CustomAppIntegrationTokenAccessPolicyArgsDict']]] = None,
                 user_authorized_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomAppIntegrationArgs.__new__(CustomAppIntegrationArgs)

            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["client_secret"] = None if client_secret is None else pulumi.Output.secret(client_secret)
            __props__.__dict__["confidential"] = confidential
            __props__.__dict__["create_time"] = create_time
            __props__.__dict__["created_by"] = created_by
            __props__.__dict__["creator_username"] = creator_username
            __props__.__dict__["integration_id"] = integration_id
            __props__.__dict__["name"] = name
            __props__.__dict__["redirect_urls"] = redirect_urls
            __props__.__dict__["scopes"] = scopes
            __props__.__dict__["token_access_policy"] = token_access_policy
            __props__.__dict__["user_authorized_scopes"] = user_authorized_scopes
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(CustomAppIntegration, __self__).__init__(
            'databricks:index/customAppIntegration:CustomAppIntegration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_id: Optional[pulumi.Input[_builtins.str]] = None,
            client_secret: Optional[pulumi.Input[_builtins.str]] = None,
            confidential: Optional[pulumi.Input[_builtins.bool]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            created_by: Optional[pulumi.Input[_builtins.int]] = None,
            creator_username: Optional[pulumi.Input[_builtins.str]] = None,
            integration_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            redirect_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token_access_policy: Optional[pulumi.Input[Union['CustomAppIntegrationTokenAccessPolicyArgs', 'CustomAppIntegrationTokenAccessPolicyArgsDict']]] = None,
            user_authorized_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'CustomAppIntegration':
        """
        Get an existing CustomAppIntegration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: OAuth client-id generated by Databricks
        :param pulumi.Input[_builtins.str] client_secret: OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        :param pulumi.Input[_builtins.bool] confidential: Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        :param pulumi.Input[_builtins.str] integration_id: Unique integration id for the custom OAuth app.
        :param pulumi.Input[_builtins.str] name: Name of the custom OAuth app. Change requires a new resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] redirect_urls: List of OAuth redirect urls.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomAppIntegrationState.__new__(_CustomAppIntegrationState)

        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["confidential"] = confidential
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["creator_username"] = creator_username
        __props__.__dict__["integration_id"] = integration_id
        __props__.__dict__["name"] = name
        __props__.__dict__["redirect_urls"] = redirect_urls
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token_access_policy"] = token_access_policy
        __props__.__dict__["user_authorized_scopes"] = user_authorized_scopes
        return CustomAppIntegration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[_builtins.str]:
        """
        OAuth client-id generated by Databricks
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[_builtins.str]:
        """
        OAuth client-secret generated by the Databricks if this is a confidential OAuth app.
        """
        return pulumi.get(self, "client_secret")

    @_builtins.property
    @pulumi.getter
    def confidential(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether an OAuth client secret is required to authenticate this client. Default to `false`. Change requires a new resource.
        """
        return pulumi.get(self, "confidential")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.int]:
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="creatorUsername")
    def creator_username(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "creator_username")

    @_builtins.property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique integration id for the custom OAuth app.
        """
        return pulumi.get(self, "integration_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the custom OAuth app. Change requires a new resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="redirectUrls")
    def redirect_urls(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of OAuth redirect urls.
        """
        return pulumi.get(self, "redirect_urls")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        OAuth scopes granted to the application. Supported scopes: `all-apis`, `sql`, `offline_access`, `openid`, `profile`, `email`.
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter(name="tokenAccessPolicy")
    def token_access_policy(self) -> pulumi.Output[Optional['outputs.CustomAppIntegrationTokenAccessPolicy']]:
        return pulumi.get(self, "token_access_policy")

    @_builtins.property
    @pulumi.getter(name="userAuthorizedScopes")
    def user_authorized_scopes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        return pulumi.get(self, "user_authorized_scopes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RepoArgs', 'Repo']

@pulumi.input_type
class RepoArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[_builtins.str],
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['RepoProviderConfigArgs']] = None,
                 sparse_checkout: Optional[pulumi.Input['RepoSparseCheckoutArgs']] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Repo resource.
        :param pulumi.Input[_builtins.str] url: The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] branch: name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        :param pulumi.Input[_builtins.str] commit_hash: Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        :param pulumi.Input[_builtins.str] git_provider: case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        :param pulumi.Input[_builtins.str] path: path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] tag: name of the tag for initial checkout.  Conflicts with `branch`.
        """
        pulumi.set(__self__, "url", url)
        if branch is not None:
            pulumi.set(__self__, "branch", branch)
        if commit_hash is not None:
            pulumi.set(__self__, "commit_hash", commit_hash)
        if git_provider is not None:
            pulumi.set(__self__, "git_provider", git_provider)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if sparse_checkout is not None:
            pulumi.set(__self__, "sparse_checkout", sparse_checkout)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        """
        return pulumi.get(self, "branch")

    @branch.setter
    def branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch", value)

    @_builtins.property
    @pulumi.getter(name="commitHash")
    def commit_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        """
        return pulumi.get(self, "commit_hash")

    @commit_hash.setter
    def commit_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_hash", value)

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        """
        return pulumi.get(self, "git_provider")

    @git_provider.setter
    def git_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_provider", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['RepoProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['RepoProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="sparseCheckout")
    def sparse_checkout(self) -> Optional[pulumi.Input['RepoSparseCheckoutArgs']]:
        return pulumi.get(self, "sparse_checkout")

    @sparse_checkout.setter
    def sparse_checkout(self, value: Optional[pulumi.Input['RepoSparseCheckoutArgs']]):
        pulumi.set(self, "sparse_checkout", value)

    @_builtins.property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the tag for initial checkout.  Conflicts with `branch`.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag", value)


@pulumi.input_type
class _RepoState:
    def __init__(__self__, *,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['RepoProviderConfigArgs']] = None,
                 sparse_checkout: Optional[pulumi.Input['RepoSparseCheckoutArgs']] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_path: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Repo resources.
        :param pulumi.Input[_builtins.str] branch: name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        :param pulumi.Input[_builtins.str] commit_hash: Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        :param pulumi.Input[_builtins.str] git_provider: case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        :param pulumi.Input[_builtins.str] path: path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] tag: name of the tag for initial checkout.  Conflicts with `branch`.
        :param pulumi.Input[_builtins.str] url: The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] workspace_path: path on Workspace File System (WSFS) in form of `/Workspace` + `path`
        """
        if branch is not None:
            pulumi.set(__self__, "branch", branch)
        if commit_hash is not None:
            pulumi.set(__self__, "commit_hash", commit_hash)
        if git_provider is not None:
            pulumi.set(__self__, "git_provider", git_provider)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if sparse_checkout is not None:
            pulumi.set(__self__, "sparse_checkout", sparse_checkout)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if workspace_path is not None:
            pulumi.set(__self__, "workspace_path", workspace_path)

    @_builtins.property
    @pulumi.getter
    def branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        """
        return pulumi.get(self, "branch")

    @branch.setter
    def branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch", value)

    @_builtins.property
    @pulumi.getter(name="commitHash")
    def commit_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        """
        return pulumi.get(self, "commit_hash")

    @commit_hash.setter
    def commit_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_hash", value)

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        """
        return pulumi.get(self, "git_provider")

    @git_provider.setter
    def git_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_provider", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['RepoProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['RepoProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="sparseCheckout")
    def sparse_checkout(self) -> Optional[pulumi.Input['RepoSparseCheckoutArgs']]:
        return pulumi.get(self, "sparse_checkout")

    @sparse_checkout.setter
    def sparse_checkout(self, value: Optional[pulumi.Input['RepoSparseCheckoutArgs']]):
        pulumi.set(self, "sparse_checkout", value)

    @_builtins.property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the tag for initial checkout.  Conflicts with `branch`.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="workspacePath")
    def workspace_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        path on Workspace File System (WSFS) in form of `/Workspace` + `path`
        """
        return pulumi.get(self, "workspace_path")

    @workspace_path.setter
    def workspace_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_path", value)


@pulumi.type_token("databricks:index/repo:Repo")
class Repo(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['RepoProviderConfigArgs', 'RepoProviderConfigArgsDict']]] = None,
                 sparse_checkout: Optional[pulumi.Input[Union['RepoSparseCheckoutArgs', 'RepoSparseCheckoutArgsDict']]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to manage [Databricks Git folders](https://docs.databricks.com/en/repos/index.html) (formerly known as Databricks Repos).

        > This resource can only be used with a workspace-level provider!

        > To create a Git folder from a private repository you need to configure Git token as described in the [documentation](https://docs.databricks.com/en/repos/index.html#configure-your-git-integration-with-databricks).  To set this token you can use GitCredential resource.

        ## Example Usage

        You can declare Pulumi-managed Git folder by specifying `url` attribute of Git repository. In addition to that you may need to specify `git_provider` attribute if Git provider doesn't belong to cloud Git providers (Github, GitLab, ...).  If `path` attribute isn't provided, then Git folder will be created in the default location:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        nutter_in_home = databricks.Repo("nutter_in_home", url="https://github.com/user/demo.git")
        ```

        ## Access Control

        * Permissions can control which groups or individual users can access repos.

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * GitCredential to manage Git credentials.
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).
        * Pipeline to deploy [Lakeflow Declarative Pipelines](https://docs.databricks.com/aws/en/dlt).
        * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * SecretAcl to manage access to [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * SecretScope to create [secret scopes](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * WorkspaceConf to manage workspace configuration for expert usage.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] branch: name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        :param pulumi.Input[_builtins.str] commit_hash: Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        :param pulumi.Input[_builtins.str] git_provider: case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        :param pulumi.Input[_builtins.str] path: path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] tag: name of the tag for initial checkout.  Conflicts with `branch`.
        :param pulumi.Input[_builtins.str] url: The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepoArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage [Databricks Git folders](https://docs.databricks.com/en/repos/index.html) (formerly known as Databricks Repos).

        > This resource can only be used with a workspace-level provider!

        > To create a Git folder from a private repository you need to configure Git token as described in the [documentation](https://docs.databricks.com/en/repos/index.html#configure-your-git-integration-with-databricks).  To set this token you can use GitCredential resource.

        ## Example Usage

        You can declare Pulumi-managed Git folder by specifying `url` attribute of Git repository. In addition to that you may need to specify `git_provider` attribute if Git provider doesn't belong to cloud Git providers (Github, GitLab, ...).  If `path` attribute isn't provided, then Git folder will be created in the default location:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        nutter_in_home = databricks.Repo("nutter_in_home", url="https://github.com/user/demo.git")
        ```

        ## Access Control

        * Permissions can control which groups or individual users can access repos.

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * GitCredential to manage Git credentials.
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).
        * Pipeline to deploy [Lakeflow Declarative Pipelines](https://docs.databricks.com/aws/en/dlt).
        * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * SecretAcl to manage access to [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * SecretScope to create [secret scopes](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * WorkspaceConf to manage workspace configuration for expert usage.

        :param str resource_name: The name of the resource.
        :param RepoArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepoArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['RepoProviderConfigArgs', 'RepoProviderConfigArgsDict']]] = None,
                 sparse_checkout: Optional[pulumi.Input[Union['RepoSparseCheckoutArgs', 'RepoSparseCheckoutArgsDict']]] = None,
                 tag: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepoArgs.__new__(RepoArgs)

            __props__.__dict__["branch"] = branch
            __props__.__dict__["commit_hash"] = commit_hash
            __props__.__dict__["git_provider"] = git_provider
            __props__.__dict__["path"] = path
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["sparse_checkout"] = sparse_checkout
            __props__.__dict__["tag"] = tag
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["workspace_path"] = None
        super(Repo, __self__).__init__(
            'databricks:index/repo:Repo',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            branch: Optional[pulumi.Input[_builtins.str]] = None,
            commit_hash: Optional[pulumi.Input[_builtins.str]] = None,
            git_provider: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['RepoProviderConfigArgs', 'RepoProviderConfigArgsDict']]] = None,
            sparse_checkout: Optional[pulumi.Input[Union['RepoSparseCheckoutArgs', 'RepoSparseCheckoutArgsDict']]] = None,
            tag: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            workspace_path: Optional[pulumi.Input[_builtins.str]] = None) -> 'Repo':
        """
        Get an existing Repo resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] branch: name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        :param pulumi.Input[_builtins.str] commit_hash: Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        :param pulumi.Input[_builtins.str] git_provider: case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        :param pulumi.Input[_builtins.str] path: path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] tag: name of the tag for initial checkout.  Conflicts with `branch`.
        :param pulumi.Input[_builtins.str] url: The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        :param pulumi.Input[_builtins.str] workspace_path: path on Workspace File System (WSFS) in form of `/Workspace` + `path`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepoState.__new__(_RepoState)

        __props__.__dict__["branch"] = branch
        __props__.__dict__["commit_hash"] = commit_hash
        __props__.__dict__["git_provider"] = git_provider
        __props__.__dict__["path"] = path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["sparse_checkout"] = sparse_checkout
        __props__.__dict__["tag"] = tag
        __props__.__dict__["url"] = url
        __props__.__dict__["workspace_path"] = workspace_path
        return Repo(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def branch(self) -> pulumi.Output[_builtins.str]:
        """
        name of the branch for initial checkout. If not specified, the default branch of the repository will be used.  Conflicts with `tag`.  If `branch` is removed, and `tag` isn't specified, then the repository will stay at the previously checked out state.
        """
        return pulumi.get(self, "branch")

    @_builtins.property
    @pulumi.getter(name="commitHash")
    def commit_hash(self) -> pulumi.Output[_builtins.str]:
        """
        Hash of the HEAD commit at time of the last executed operation. It won't change if you manually perform pull operation via UI or API
        """
        return pulumi.get(self, "commit_hash")

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> pulumi.Output[_builtins.str]:
        """
        case insensitive name of the Git provider.  Following values are supported right now (could be a subject for a change, consult [Repos API documentation](https://docs.databricks.com/dev-tools/api/latest/repos.html)): `gitHub`, `gitHubEnterprise`, `bitbucketCloud`, `bitbucketServer`, `azureDevOpsServices`, `gitLab`, `gitLabEnterpriseEdition`, `awsCodeCommit`.
        """
        return pulumi.get(self, "git_provider")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        path to put the checked out Git folder. If not specified, , then the Git folder will be created in the default location.  If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.RepoProviderConfig']]:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="sparseCheckout")
    def sparse_checkout(self) -> pulumi.Output[Optional['outputs.RepoSparseCheckout']]:
        return pulumi.get(self, "sparse_checkout")

    @_builtins.property
    @pulumi.getter
    def tag(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        name of the tag for initial checkout.  Conflicts with `branch`.
        """
        return pulumi.get(self, "tag")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the Git Repository to clone from. If the value changes, Git folder is re-created.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="workspacePath")
    def workspace_path(self) -> pulumi.Output[_builtins.str]:
        """
        path on Workspace File System (WSFS) in form of `/Workspace` + `path`
        """
        return pulumi.get(self, "workspace_path")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataClassificationCatalogConfigResult',
    'AwaitableGetDataClassificationCatalogConfigResult',
    'get_data_classification_catalog_config',
    'get_data_classification_catalog_config_output',
]

@pulumi.output_type
class GetDataClassificationCatalogConfigResult:
    """
    A collection of values returned by getDataClassificationCatalogConfig.
    """
    def __init__(__self__, auto_tag_configs=None, id=None, included_schemas=None, name=None, provider_config=None):
        if auto_tag_configs and not isinstance(auto_tag_configs, list):
            raise TypeError("Expected argument 'auto_tag_configs' to be a list")
        pulumi.set(__self__, "auto_tag_configs", auto_tag_configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if included_schemas and not isinstance(included_schemas, dict):
            raise TypeError("Expected argument 'included_schemas' to be a dict")
        pulumi.set(__self__, "included_schemas", included_schemas)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="autoTagConfigs")
    def auto_tag_configs(self) -> Sequence['outputs.GetDataClassificationCatalogConfigAutoTagConfigResult']:
        """
        (list of AutoTaggingConfig) - List of auto-tagging configurations for this catalog.
        Empty list means no auto-tagging is enabled
        """
        return pulumi.get(self, "auto_tag_configs")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includedSchemas")
    def included_schemas(self) -> 'outputs.GetDataClassificationCatalogConfigIncludedSchemasResult':
        """
        (CatalogConfigSchemaNames) - Schemas to include in the scan. Empty list is not supported as it results in a no-op
        scan. If `included_schemas` is not set, all schemas are scanned
        """
        return pulumi.get(self, "included_schemas")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Resource name in the format: catalogs/{catalog_name}/config
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetDataClassificationCatalogConfigProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetDataClassificationCatalogConfigResult(GetDataClassificationCatalogConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataClassificationCatalogConfigResult(
            auto_tag_configs=self.auto_tag_configs,
            id=self.id,
            included_schemas=self.included_schemas,
            name=self.name,
            provider_config=self.provider_config)


def get_data_classification_catalog_config(name: Optional[_builtins.str] = None,
                                           provider_config: Optional[Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict']] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataClassificationCatalogConfigResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the Data Classification configuration for a Unity Catalog catalog.

    To read the Data Classification configuration, you must have browse permissions on the catalog.

    > **Note** This data source can only be used with a workspace-level provider.

    ## Example Usage

    To get the Data Classification configuration for a catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    prod = databricks.get_catalog(name="prod_catalog")
    prod_config = databricks.get_data_classification_catalog_config(name=f"catalogs/{prod.name}/config")
    pulumi.export("autoTagConfigs", prod_config.auto_tag_configs)
    ```


    :param _builtins.str name: Resource name in the format: catalogs/{catalog_name}/config
    :param Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDataClassificationCatalogConfig:getDataClassificationCatalogConfig', __args__, opts=opts, typ=GetDataClassificationCatalogConfigResult).value

    return AwaitableGetDataClassificationCatalogConfigResult(
        auto_tag_configs=pulumi.get(__ret__, 'auto_tag_configs'),
        id=pulumi.get(__ret__, 'id'),
        included_schemas=pulumi.get(__ret__, 'included_schemas'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_data_classification_catalog_config_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  provider_config: Optional[pulumi.Input[Optional[Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict']]]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDataClassificationCatalogConfigResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the Data Classification configuration for a Unity Catalog catalog.

    To read the Data Classification configuration, you must have browse permissions on the catalog.

    > **Note** This data source can only be used with a workspace-level provider.

    ## Example Usage

    To get the Data Classification configuration for a catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    prod = databricks.get_catalog(name="prod_catalog")
    prod_config = databricks.get_data_classification_catalog_config(name=f"catalogs/{prod.name}/config")
    pulumi.export("autoTagConfigs", prod_config.auto_tag_configs)
    ```


    :param _builtins.str name: Resource name in the format: catalogs/{catalog_name}/config
    :param Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDataClassificationCatalogConfig:getDataClassificationCatalogConfig', __args__, opts=opts, typ=GetDataClassificationCatalogConfigResult)
    return __ret__.apply(lambda __response__: GetDataClassificationCatalogConfigResult(
        auto_tag_configs=pulumi.get(__response__, 'auto_tag_configs'),
        id=pulumi.get(__response__, 'id'),
        included_schemas=pulumi.get(__response__, 'included_schemas'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAwsBucketPolicyResult',
    'AwaitableGetAwsBucketPolicyResult',
    'get_aws_bucket_policy',
    'get_aws_bucket_policy_output',
]

@pulumi.output_type
class GetAwsBucketPolicyResult:
    """
    A collection of values returned by getAwsBucketPolicy.
    """
    def __init__(__self__, aws_partition=None, bucket=None, databricks_account_id=None, databricks_e2_account_id=None, full_access_role=None, id=None, json=None):
        if aws_partition and not isinstance(aws_partition, str):
            raise TypeError("Expected argument 'aws_partition' to be a str")
        pulumi.set(__self__, "aws_partition", aws_partition)
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if databricks_account_id and not isinstance(databricks_account_id, str):
            raise TypeError("Expected argument 'databricks_account_id' to be a str")
        pulumi.set(__self__, "databricks_account_id", databricks_account_id)
        if databricks_e2_account_id and not isinstance(databricks_e2_account_id, str):
            raise TypeError("Expected argument 'databricks_e2_account_id' to be a str")
        pulumi.set(__self__, "databricks_e2_account_id", databricks_e2_account_id)
        if full_access_role and not isinstance(full_access_role, str):
            raise TypeError("Expected argument 'full_access_role' to be a str")
        pulumi.set(__self__, "full_access_role", full_access_role)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if json and not isinstance(json, str):
            raise TypeError("Expected argument 'json' to be a str")
        pulumi.set(__self__, "json", json)

    @_builtins.property
    @pulumi.getter(name="awsPartition")
    def aws_partition(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "aws_partition")

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> _builtins.str:
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter(name="databricksAccountId")
    @_utilities.deprecated("""databricks_account_id will be will be removed in the next major release.""")
    def databricks_account_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "databricks_account_id")

    @_builtins.property
    @pulumi.getter(name="databricksE2AccountId")
    def databricks_e2_account_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "databricks_e2_account_id")

    @_builtins.property
    @pulumi.getter(name="fullAccessRole")
    def full_access_role(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "full_access_role")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def json(self) -> _builtins.str:
        """
        (Read-only) AWS IAM Policy JSON document to grant Databricks full access to bucket.
        """
        return pulumi.get(self, "json")


class AwaitableGetAwsBucketPolicyResult(GetAwsBucketPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsBucketPolicyResult(
            aws_partition=self.aws_partition,
            bucket=self.bucket,
            databricks_account_id=self.databricks_account_id,
            databricks_e2_account_id=self.databricks_e2_account_id,
            full_access_role=self.full_access_role,
            id=self.id,
            json=self.json)


def get_aws_bucket_policy(aws_partition: Optional[_builtins.str] = None,
                          bucket: Optional[_builtins.str] = None,
                          databricks_account_id: Optional[_builtins.str] = None,
                          databricks_e2_account_id: Optional[_builtins.str] = None,
                          full_access_role: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsBucketPolicyResult:
    """
    This datasource configures a simple access policy for AWS S3 buckets, so that Databricks can access data in it.

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_databricks as databricks

    this_s3_bucket = aws.index.S3Bucket("this",
        bucket=<unique_bucket_name>,
        force_destroy=True)
    this = databricks.get_aws_bucket_policy(bucket=this_s3_bucket["bucket"])
    this_s3_bucket_policy = aws.index.S3BucketPolicy("this",
        bucket=this_s3_bucket.id,
        policy=this.json)
    ```

    Bucket policy with full access:


    :param _builtins.str aws_partition: AWS partition. The options are `aws`, `aws-us-gov`, or `aws-us-gov-dod`. Defaults to `aws`
    :param _builtins.str bucket: AWS S3 Bucket name for which to generate the policy document. The name must follow the [S3 bucket naming rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html).
    :param _builtins.str databricks_e2_account_id: Your Databricks account ID. Used to generate  restrictive IAM policies that will increase the security of your root bucket
    :param _builtins.str full_access_role: Data access role that can have full access for this bucket
    """
    __args__ = dict()
    __args__['awsPartition'] = aws_partition
    __args__['bucket'] = bucket
    __args__['databricksAccountId'] = databricks_account_id
    __args__['databricksE2AccountId'] = databricks_e2_account_id
    __args__['fullAccessRole'] = full_access_role
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAwsBucketPolicy:getAwsBucketPolicy', __args__, opts=opts, typ=GetAwsBucketPolicyResult).value

    return AwaitableGetAwsBucketPolicyResult(
        aws_partition=pulumi.get(__ret__, 'aws_partition'),
        bucket=pulumi.get(__ret__, 'bucket'),
        databricks_account_id=pulumi.get(__ret__, 'databricks_account_id'),
        databricks_e2_account_id=pulumi.get(__ret__, 'databricks_e2_account_id'),
        full_access_role=pulumi.get(__ret__, 'full_access_role'),
        id=pulumi.get(__ret__, 'id'),
        json=pulumi.get(__ret__, 'json'))
def get_aws_bucket_policy_output(aws_partition: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                                 databricks_account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 databricks_e2_account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 full_access_role: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsBucketPolicyResult]:
    """
    This datasource configures a simple access policy for AWS S3 buckets, so that Databricks can access data in it.

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_databricks as databricks

    this_s3_bucket = aws.index.S3Bucket("this",
        bucket=<unique_bucket_name>,
        force_destroy=True)
    this = databricks.get_aws_bucket_policy(bucket=this_s3_bucket["bucket"])
    this_s3_bucket_policy = aws.index.S3BucketPolicy("this",
        bucket=this_s3_bucket.id,
        policy=this.json)
    ```

    Bucket policy with full access:


    :param _builtins.str aws_partition: AWS partition. The options are `aws`, `aws-us-gov`, or `aws-us-gov-dod`. Defaults to `aws`
    :param _builtins.str bucket: AWS S3 Bucket name for which to generate the policy document. The name must follow the [S3 bucket naming rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html).
    :param _builtins.str databricks_e2_account_id: Your Databricks account ID. Used to generate  restrictive IAM policies that will increase the security of your root bucket
    :param _builtins.str full_access_role: Data access role that can have full access for this bucket
    """
    __args__ = dict()
    __args__['awsPartition'] = aws_partition
    __args__['bucket'] = bucket
    __args__['databricksAccountId'] = databricks_account_id
    __args__['databricksE2AccountId'] = databricks_e2_account_id
    __args__['fullAccessRole'] = full_access_role
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAwsBucketPolicy:getAwsBucketPolicy', __args__, opts=opts, typ=GetAwsBucketPolicyResult)
    return __ret__.apply(lambda __response__: GetAwsBucketPolicyResult(
        aws_partition=pulumi.get(__response__, 'aws_partition'),
        bucket=pulumi.get(__response__, 'bucket'),
        databricks_account_id=pulumi.get(__response__, 'databricks_account_id'),
        databricks_e2_account_id=pulumi.get(__response__, 'databricks_e2_account_id'),
        full_access_role=pulumi.get(__response__, 'full_access_role'),
        id=pulumi.get(__response__, 'id'),
        json=pulumi.get(__response__, 'json')))
